@@ -106,17 +106,25 @@ class ModRana(object):
         # early CLI tasks might need a "silent" modRana
         # so the startup announcement is here
         print(" == modRana Starting == ")
-
-        # add the paths handling core module
-        self.paths = paths.Paths(self)
-
-        # print(version string)
-        version = self.paths.getVersionString()
+        # load the version string (needs to be done here
+        # as PWD might change after the paths module is
+        # imported, for example when running
+        # with the Qt 5 GUI)
+        paths.loadVersionString()
+        version = paths.VERSION_STRING
         if version is None:
             version = "unknown version"
         print("  %s" % version)
         print("  Python %s" % platform.python_version())
 
+        # load the device module now as it might override
+        # the default profile directory, so it needs to be
+        # before ve init the core paths module
+        self._loadDeviceModule()
+
+        # initialize the paths handling core module
+        self.paths = paths.Paths(self)
+
         # add the configs handling core module
         self.configs = configs.Configs(self)
 
@@ -127,21 +135,18 @@ class ModRana(object):
 
         if self.optLoadingOK:
             savedVersionString = self.get('modRanaVersionString', "")
-            versionStringFromFile = self.paths.getVersionString()
+            versionStringFromFile = paths.VERSION_STRING
             if savedVersionString != versionStringFromFile:
                 print("modRana: possible upgrade detected")
                 self._postUpgradeCheck()
 
         # save current version string
-        self.set('modRanaVersionString', self.paths.getVersionString())
+        self.set('modRanaVersionString', paths.VERSION_STRING)
 
         # load all configuration files
         self.configs.loadAll()
 
-        # start loading modules
-
-        # device module first
-        self._loadDeviceModule()
+        # start loading other modules
 
         # handle tasks that require the device
         # module but not GUI
@@ -253,7 +258,10 @@ class ModRana(object):
             gui = self._loadModule("gui_gtk", "gui")
         elif GUIModuleId == "QML":
             gui = self._loadModule("gui_qml", "gui")
-            # make device module available to the GUI module
+        elif GUIModuleId == "qt5":
+            gui = self._loadModule("gui_qt5", "gui")
+
+        # make device module available to the GUI module
         if gui:
             gui.setSubtypeId(subtypeId)
             gui.dmod = self.dmod
@@ -814,8 +822,7 @@ class ModRana(object):
         else:
             print("* timing list empty *")
 
-
-if __name__ == "__main__":
+def setCorrectCWD():
     # change to folder where the main modRana file is located
     # * this enables to run modRana with absolute path without adverse
     # effect such as modRana not finding modules or
@@ -825,6 +832,21 @@ if __name__ == "__main__":
     # that expect to be placed to path work correctly
     sys.path.append(os.path.join(currentAbsolutePath, 'modules'))
 
+modrana = None
+dmod = None
+gui = None
+def start():
+    """This function is used when starting modRana with PyOtherSide"""
+    global modrana
+    global dmod
+    global gui
+    setCorrectCWD()
+    modrana = ModRana()
+    dmod = modrana.dmod
+    gui = modrana.gui
+
+if __name__ == "__main__":
+    setCorrectCWD()
     # check if reload has been requested
     reloadArg = "--reload"
     if len(sys.argv) >= 3 and sys.argv[1] == reloadArg:
@@ -836,6 +858,6 @@ if __name__ == "__main__":
         callArgs.extend(sys.argv[3:])
         subprocess.call(callArgs)
     else:
-        program = ModRana()
+        start()
 
 
